==> haskell-microlens-aeson-2.5.2-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-aeson
version:              2.5.2
visibility:           public
id:                   microlens-aeson-2.5.2-CGAtJMM23yGOsCVYD2HXG
key:                  microlens-aeson-2.5.2-CGAtJMM23yGOsCVYD2HXG
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury

maintainer:           Colin Woodbury <colin@fosskers.ca>
author:               Colin Woodbury
homepage:             http://github.com/fosskers/microlens-aeson/
synopsis:             Law-abiding lenses for Aeson, using microlens
description:          Law-abiding lenses for Aeson, using microlens.
category:             Numeric
abi:                  9f794ecc2329f76a51a3963e54089e85
exposed:              True
exposed-modules:      Lens.Micro.Aeson
hidden-modules:       Lens.Micro.Aeson.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/microlens-aeson-2.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/microlens-aeson-2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-aeson
hs-libraries:         HSmicrolens-aeson-2.5.2-CGAtJMM23yGOsCVYD2HXG
depends:
    aeson-2.1.2.1-IkP1OjeNuTxglWxWeIvI9
    attoparsec-0.14.4-IUoeEKVn7Gr6GqDDI9lyTI base-4.16.4.0
    bytestring-0.11.4.0 hashable-1.4.4.0-DtL5AH6y1if92iaAq0qoKj
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    scientific-0.3.7.0-8ausramh0PCAAyDmAQtWkI text-1.2.5.0
    vector-0.13.1.0-1Hbj4hORR7KGMeSpv0BhQN

haddock-interfaces:
    /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock

haddock-html:         /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-aeson-2.5.2-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-aeson
version:              2.5.2
visibility:           public
id:                   microlens-aeson-2.5.2-FMdSexPRW2UGK2TVRkU3Ab
key:                  microlens-aeson-2.5.2-FMdSexPRW2UGK2TVRkU3Ab
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson, (C) 2013 Edward A. Kmett, (C) 2015 Colin Woodbury

maintainer:           Colin Woodbury <colin@fosskers.ca>
author:               Colin Woodbury
homepage:             http://github.com/fosskers/microlens-aeson/
synopsis:             Law-abiding lenses for Aeson, using microlens
description:          Law-abiding lenses for Aeson, using microlens.
category:             Numeric
abi:                  bb884b0bd795b063102e7fe92757c607
exposed:              True
exposed-modules:      Lens.Micro.Aeson
hidden-modules:       Lens.Micro.Aeson.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/microlens-aeson-2.5.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/microlens-aeson-2.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microlens-aeson
hs-libraries:         HSmicrolens-aeson-2.5.2-FMdSexPRW2UGK2TVRkU3Ab
depends:
    aeson-2.1.2.1-I893iKJ0oHPJ1jEwOVWed6
    attoparsec-0.14.4-DN7s9Fr9c113K5agmmE0LB base-4.16.4.0
    bytestring-0.11.4.0 hashable-1.4.4.0-BrYG523VafVKM4yDK0K7G3
    microlens-0.4.13.1-HPplyG5VOciEIF62YegSgA
    scientific-0.3.7.0-7nXcZobZD337Jkf1NR7gHa text-1.2.5.0
    vector-0.13.1.0-Gf2urNiIAD32gZDiWE6SSZ

haddock-interfaces:
    /usr/share/doc/haskell-microlens-aeson/html/microlens-aeson.haddock

haddock-html:         /usr/share/doc/haskell-microlens-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
